
from setuptools import setup, find_packages



setup(name='pykun',

      version='0.1.3',

      url='https://github.com/kunrunic/pykun',

      license='MIT',

      author='Jho Sung Jun',

      author_email='kunrunic7272@gmail.com',

      description='Develop a Callection of useful packages',

      packages=find_packages(),

      long_description=open('README.md').read(),

      zip_safe=False,

      setup_requires=[],

      test_suite='')
